﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = False

    ## These control the width and height of the screen.
    config.screen_width = 1366
    config.screen_height = 768

    config.thumbnail_width = 320
    config.thumbnail_height = 180

    ## This controls the title of the window, when Ren'Py is running in a window.
    config.window_title = u"Night at the Hospital"

    # These control the name and version of the game, that are reported
    # with tracebacks and other debugging logs.
    config.name = "Night at the Hospital"
    config.version = "1.01"

#    config.window_icon = "GUI/icon.png"
#    config.windows_icon = "GUI/icon_w1.png"
#    if persistent.fancy_cursor:
#        config.mouse = {"default" :[("GUI/cursor.png", 3, 3)]}


    #########################################
    # Themes
    ## The theme function takes a number of parameters that can customize the color scheme.

    theme.a_white_tulip(
        ## Theme: A White Tulip
        ## Scheme Muted Horror
        ## The color of an idle widget face.
        widget = "#777777",
        ## The color of a focused widget face.
        widget_hover = "#73735C",
        ## The color of the text in a selected widget. (For example, the current value of a preference.)
        widget_selected = "#000000",
        ## The color of a disabled widget face. 
        disabled = "#73735C",
        ## The color of a frame containing widgets.
        frame = "#555544",
        ## The background of the main menu. This can be a color beginning with '#', or an image filename. The latter should take up the full height and width of the screen.
        mm_root = "GUI/title.jpg",
        ## The background of the game menu. This can be a color beginning with '#', or an image filename. The latter should take up the full height and width of the screen.
        gm_root = "GUI/navigation_ground.png",
        ## And we're done with the theme. The theme will customize various styles, so if we want to change them, we should do so below.            
        )

    style.default.font = "GUI/Chivo-Regular.ttf" # The file containing the default font.
    style.default.size = 22 # The default size of text. Note that these only change the size of some of the text. Other buttons have their own styles.
    style.default.color = "#fff"

    #########################################
    ## These settings let you change some of the sounds that are used by Ren'Py.

    ## Set this to False if the game does not have any sound effects.
    config.has_sound = True
    ## Set this to False if the game does not have any music.
    config.has_music = True
    ## Set this to False if the game does not have voicing.
    config.has_voice = False

    ## Sounds that are used when button and imagemaps are clicked.
    style.imagemap_button.hover_sound = HOVER
    style.imagemap_button.activate_sound = CLICK

    ## Sounds that are used when entering and exiting the game menu.
    # config.enter_sound = "click.wav"
    # config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.
    # config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.
    config.main_menu_music = THEME[0]

    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = "README.html"

    #########################################
    ## Transitions.
    ## Used when entering the game menu from the game.
    config.enter_transition = dissolve
    ## Used when exiting the game menu to the game.
    config.exit_transition = dissolve
    ## Used between screens of the game menu.
    config.intra_transition = dissolve
    ## Used when entering the game menu from the main menu.
    config.main_game_transition = dissolve
    ## Used when returning to the main menu from the game.
    config.game_main_transition = dissolve
    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = dissolve
    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = dissolve
    ## Used when a game is loaded.
    config.after_load_transition = dissolve
    ## Used when the window is shown.
    config.window_show_transition = dissolve
    ## Used when the window is hidden.
    config.window_hide_transition = dissolve


    #########################################
    ## This is the name of the directory where the game's data is stored. (It needs to be set early, before any other init code is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "Night at the Hospital-1365123287"

init -1 python hide:
    #########################################
    ## Default values of Preferences. Note: These options are only evaluated the first time a game is run. To have them run a second time, delete game/saves/persistent

    ## Should we start in fullscreen mode?
    config.default_fullscreen = False
    ## The default text speed in characters per second. 0 is infinite.
    config.default_text_cps = 80
# Set a default value for the auto-forward time, and note that AFM is turned off by default.    
    config.default_afm_time = 0
    config.default_afm_enable = False
    #########################################
    ## More customizations can go here.

                         
## This section contains information about how to build your project into 
## distribution files.
init python:
    
    ## The name that's used for directories and archive files. For example, if
    ## this is 'mygame-1.0', the windows distribution will be in the
    ## directory 'mygame-1.0-win', in the 'mygame-1.0-win.zip' file.
    build.directory_name = "Night at the Hospital-1.0"
    
    ## The name that's uses for executables - the program that users will run
    ## to start the game. For example, if this is 'mygame', then on Windows,
    ## users can click 'mygame.exe' to start the game.
    build.executable_name = "Night at the Hospital"
    
    ## If True, Ren'Py will include update information into packages. This
    ## allows the updater to run.
    build.include_update = False
    
    ## File patterns:
    ## 
    ## The following functions take file patterns. File patterns are case-
    ## insensitive, and matched against the path relative to the base
    ## directory, with and without a leading /. If multiple patterns match,
    ## the first is used.
    ##    
    ##
    ## In a pattern:
    ##
    ## / 
    ##     Is the directory separator.
    ## *
    ##     Matches all characters, except the directory separator.
    ## **
    ##     Matches all characters, including the directory separator.
    ##
    ## For example:
    ##
    ## *.txt
    ##     Matches txt files in the base directory.
    ## game/**.ogg
    ##     Matches ogg files in the game directory or any of its subdirectories.
    ## **.psd
    ##    Matches psd files anywhere in the project.

    ## Classify files as None to exclude them from the built distributions.

    build.classify('**~', None)
    build.classify('**.bak', None)
    build.classify('**/.**', None)
    build.classify('**/#**', None)
    build.classify('**/thumbs.db', None)
    
    ## To archive files, classify them as 'archive'.
    
    # build.classify('game/**.png', 'archive')
    # build.classify('game/**.jpg', 'archive')

    ## Files matching documentation patterns are duplicated in a mac app
    ## build, so they appear in both the app and the zip file.

    build.documentation('*.html')
    build.documentation('*.txt')
    